#!/bin/sh

#INSTALL_DIR="/opt";
INSTALL_DIR=`pwd`
TOP_DIR="gcluster";
CUR_USER=$USER;

usage()
{
    echo -e "usage\n$0 gccli_pack_file";
}


if [ $# -ne 1 ]; then
    echo "Wrong arguments !";
    usage;
    exit 1;
fi

PACK_FILE=$1;
if [ ! -f $PACK_FILE ]; then
    echo "$PACK_FILE is not found !";
    usage;
    exit 1;
fi

if [ -d "$INSTALL_DIR/$TOP_DIR" ]; then
    echo -e "Gcluster or gccli seems has been installed already !\nPlease remove any gcluster or gccli from this machine and make sure the direcory \"$INSTALL_DIR/$TOP_DIR\" doesn't exist in advance !";
    exit 1;
fi

mkdir -p $INSTALL_DIR/$TOP_DIR;
ret=$?;
if [ $ret -ne 0 ]; then
    echo "Can't create file under $INSTALL_DIR by user $CUR_USER!";
    exit $ret;
fi
rm -rf $INSTALL_DIR/$TOP_DIR;

tar xvf $PACK_FILE -C $INSTALL_DIR;
ret=$?;
if [ $ret -ne 0 ]; then
    echo "Install gccli failed($ret) !";
    exit $ret;
fi

chown $CUR_USER:$CUR_USER $INSTALL_DIR/$TOP_DIR -R;
ret=$?;
if [ $ret -ne 0 ]; then
    echo "Set ownership failed($ret) for \"$INSTALL_DIR/$TOP_DIR\" !";
    exit $ret;
fi

# generate gccli
GCLUSTER_HOME_DIR=$INSTALL_DIR/$TOP_DIR/server
gccli=$GCLUSTER_HOME_DIR/bin/gccli
cat << EOF >> $gccli
export GCLUSTER_BASE=$INSTALL_DIR/$TOP_DIR
export GCLUSTER_HOME=$INSTALL_DIR/$TOP_DIR/server
export GCLUSTER_SID=$TOP_DIR
export LD_LIBRARY_PATH=\$LD_LIBRARY_PATH:\$GCLUSTER_HOME/lib/gbase
$GCLUSTER_HOME_DIR/bin/gbase "\$@"
EOF

#generate gcdump
gcdump=$GCLUSTER_HOME_DIR/bin/gcdump
cat << EOF >> $gcdump
export GCLUSTER_BASE=$INSTALL_DIR/$TOP_DIR
export GCLUSTER_SID=$TOP_DIR
$GCLUSTER_HOME_DIR/bin/dump "\$@"
EOF

ret=$?;
if [ $ret -ne 0 ]; then
    echo "install gccli failed($ret) !";
    exit $ret;
fi

chmod 755 $gccli
chmod 755 $gcdump

echo -e "Installation finished. \n\
Please run \"$gccli -uUSER -pPASSWORD -hGCLUSTER_NODE_IP\" for checking.";

